@@ -36,8 +36,11 @@ from . import (
     DbApp,
     UpdateApp,
     ZipCollectApp,
-    GenerateConfigApp
+    GenerateConfigApp,
+    GenerateSolutionApp
 )
+from traitlets.traitlets import MetaHasTraits
+from typing import List
 
 aliases = {}
 aliases.update(nbgrader_aliases)
@@ -291,17 +294,25 @@ class NbGraderApp(NbGrader):
                 """
             ).strip()
         ),
+        generate_solution=(
+            GenerateSolutionApp,
+            dedent(
+                """
+                Generates the solution for the given assignment.
+                """
+            ).strip()
+        ),
     )
 
     @default("classes")
-    def _classes_default(self):
+    def _classes_default(self) -> List[MetaHasTraits]:
         return self.all_configurable_classes()
 
     @catch_config_error
-    def initialize(self, argv=None):
+    def initialize(self, argv: List[str] = None) -> None:
         super(NbGraderApp, self).initialize(argv)
 
-    def start(self):
+    def start(self) -> None:
         # check: is there a subapp given?
         if self.subapp is None:
             print("No command given (run with --help for options). List of subcommands:\n")
